@@ -16,7 +16,7 @@ $opts->analyze(\@ARGV);
 
 my($hash)=Meta::Baseline::Aegis::extra_files_hash($abso);
 Meta::Utils::Hash::print(Meta::Utils::Output::get_file(),$hash);
-Meta::Utils::System::exit(1);
+Meta::Utils::System::exit_ok();
 
 __END__
 
@@ -49,7 +49,7 @@ Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111, USA.
 
 	MANIFEST: base_aegi_extra_files.pl
 	PROJECT: meta
-	VERSION: 0.25
+	VERSION: 0.26
 
 =head1 SYNOPSIS
 
@@ -148,6 +148,7 @@ None.
 	0.23 MV web site automation
 	0.24 MV SEE ALSO section fix
 	0.25 MV move tests to modules
+	0.26 MV md5 issues
 
 =head1 SEE ALSO
 
