@@ -15,7 +15,7 @@ $opts->analyze(\@ARGV);
 my($file)=$ARGV[0];
 my($dict)=Meta::Baseline::Aegis::which("data/baseline/dict.txt");
 my($scod)=Meta::Utils::System::system_nodie("aspell",["--dont-backup","--mode=sgml","--personal",$dict,"--check",$file]);
-Meta::Utils::System::exit(1);
+Meta::Utils::System::exit_ok();
 
 __END__
 
@@ -48,7 +48,7 @@ Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111, USA.
 
 	MANIFEST: base_tool_aspell.pl
 	PROJECT: meta
-	VERSION: 0.19
+	VERSION: 0.20
 
 =head1 SYNOPSIS
 
@@ -139,6 +139,7 @@ None.
 	0.17 MV web site automation
 	0.18 MV SEE ALSO section fix
 	0.19 MV move tests to modules
+	0.20 MV md5 issues
 
 =head1 SEE ALSO
 
