@@ -14,7 +14,7 @@ $opts->set_free_allo(0);
 $opts->analyze(\@ARGV);
 
 Meta::Utils::File::Symlink::check($dire,$verb);
-Meta::Utils::System::exit(1);
+Meta::Utils::System::exit_ok();
 
 __END__
 
@@ -47,7 +47,7 @@ Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111, USA.
 
 	MANIFEST: base_tool_symlink_check.pl
 	PROJECT: meta
-	VERSION: 0.23
+	VERSION: 0.24
 
 =head1 SYNOPSIS
 
@@ -152,6 +152,7 @@ None.
 	0.21 MV web site automation
 	0.22 MV SEE ALSO section fix
 	0.23 MV move tests to modules
+	0.24 MV md5 issues
 
 =head1 SEE ALSO
 
