@@ -5,7 +5,7 @@ package Meta::Cgi::Patch;
 use strict qw(vars refs subs);
 
 our($VERSION,@ISA);
-$VERSION="0.01";
+$VERSION="0.02";
 @ISA=qw();
 
 #sub new($);
@@ -14,9 +14,9 @@ $VERSION="0.01";
 #__DATA__
 
 sub new($) {
-	my($clas)=@_;
+	my($class)=@_;
 	my($self)={};
-	bless($self,$clas);
+	bless($self,$class);
 	return($self);
 }
 
@@ -62,7 +62,7 @@ Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111, USA.
 
 	MANIFEST: Patch.pm
 	PROJECT: meta
-	VERSION: 0.01
+	VERSION: 0.02
 
 =head1 SYNOPSIS
 
@@ -121,6 +121,7 @@ None.
 
 	0.00 MV SEE ALSO section fix
 	0.01 MV bring movie data
+	0.02 MV md5 issues
 
 =head1 SEE ALSO
 
