@@ -7,7 +7,7 @@ use SOAP::Transport::TCP qw();
 use Meta::Baseline::Aegis qw();
 
 our($VERSION,@ISA);
-$VERSION="0.10";
+$VERSION="0.11";
 @ISA=qw(SOAP::Transport::TCP::Server);
 
 #sub new($);
@@ -16,7 +16,7 @@ $VERSION="0.10";
 #__DATA__
 
 sub new($) {
-	my($clas)=@_;
+	my($class)=@_;
 	my($self)=SOAP::Transport::TCP::Server->new(
 		LocalAddr=>'localhost',
 		LocalPort=>10001,
@@ -28,7 +28,7 @@ sub new($) {
 	$self->objects_by_reference("Meta::Info::Author");
 	#$self->uri("uri");
 	#$self->objects_by_reference
-	#bless($self,$clas);# this somehow prevents server from running
+	#bless($self,$class);# this somehow prevents server from running
 	return($self);
 }
 
@@ -70,7 +70,7 @@ Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111, USA.
 
 	MANIFEST: Server.pm
 	PROJECT: meta
-	VERSION: 0.10
+	VERSION: 0.11
 
 =head1 SYNOPSIS
 
@@ -132,6 +132,7 @@ None.
 	0.08 MV website construction
 	0.09 MV web site automation
 	0.10 MV SEE ALSO section fix
+	0.11 MV md5 issues
 
 =head1 SEE ALSO
 
