@@ -6,7 +6,7 @@ use strict qw(vars refs subs);
 use XMLRPC::Lite qw();
 
 our($VERSION,@ISA);
-$VERSION="0.09";
+$VERSION="0.10";
 @ISA=qw(XMLRPC::Lite);
 
 #sub new($);
@@ -15,10 +15,10 @@ $VERSION="0.09";
 #__DATA__
 
 sub new($) {
-	my($clas)=@_;
+	my($class)=@_;
 	my($self)=XMLRPC::Lite->new();
 	$self->proxy('http://localhost/RPC2:10001');
-	bless($self,$clas);
+	bless($self,$class);
 	return($self);
 }
 
@@ -60,7 +60,7 @@ Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111, USA.
 
 	MANIFEST: Client.pm
 	PROJECT: meta
-	VERSION: 0.09
+	VERSION: 0.10
 
 =head1 SYNOPSIS
 
@@ -119,6 +119,7 @@ None.
 	0.07 MV website construction
 	0.08 MV web site automation
 	0.09 MV SEE ALSO section fix
+	0.10 MV md5 issues
 
 =head1 SEE ALSO
 
