@@ -4,9 +4,10 @@ package Meta::Db::Reserved;
 
 use strict qw(vars refs subs);
 use Meta::Ds::Set qw();
+use Meta::Error::Simple qw();
 
 our($VERSION,@ISA);
-$VERSION="0.05";
+$VERSION="0.06";
 @ISA=qw();
 
 #sub BEGIN();
@@ -552,7 +553,7 @@ sub check($) {
 sub make_sure($) {
 	my($word)=@_;
 	if(!check($word)) {
-		Meta::Utils::System::die("word [".$word."] is an SQL reserved word");
+		throw Meta::Error::Simple("word [".$word."] is an SQL reserved word");
 	}
 }
 
@@ -594,7 +595,7 @@ Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111, USA.
 
 	MANIFEST: Reserved.pm
 	PROJECT: meta
-	VERSION: 0.05
+	VERSION: 0.06
 
 =head1 SYNOPSIS
 
@@ -694,10 +695,11 @@ None.
 	0.03 MV web site automation
 	0.04 MV SEE ALSO section fix
 	0.05 MV web site development
+	0.06 MV md5 issues
 
 =head1 SEE ALSO
 
-Meta::Ds::Set(3), strict(3)
+Meta::Ds::Set(3), Meta::Error::Simple(3), strict(3)
 
 =head1 TODO
 
