@@ -63,7 +63,7 @@ while($file=<STDIN>) {
 	#Meta::Utils::Output::print("/index.html"."\n");
 }
 
-Meta::Utils::System::exit(1);
+Meta::Utils::System::exit_ok();
 
 __END__
 
@@ -96,7 +96,7 @@ Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111, USA.
 
 	MANIFEST: development_apache_dir.pl
 	PROJECT: meta
-	VERSION: 0.03
+	VERSION: 0.04
 
 =head1 SYNOPSIS
 
@@ -193,6 +193,7 @@ None.
 	0.01 MV web site automation
 	0.02 MV SEE ALSO section fix
 	0.03 MV move tests to modules
+	0.04 MV md5 issues
 
 =head1 SEE ALSO
 
