@@ -4,11 +4,11 @@ package Meta::Ds::Carray;
 
 use strict qw(vars refs subs);
 use Meta::Utils::Arg qw();
-use Meta::Utils::System qw();
 use Meta::Utils::Output qw();
+use Meta::Error::Simple qw();
 
 our($VERSION,@ISA);
-$VERSION="0.12";
+$VERSION="0.13";
 @ISA=qw();
 
 #sub new($);
@@ -24,9 +24,9 @@ $VERSION="0.12";
 #__DATA__
 
 sub new($) {
-	my($clas)=@_;
+	my($class)=@_;
 	my($self)={};
-	bless($self,$clas);
+	bless($self,$class);
 	$self->{LIST}=[];
 	return($self);
 }
@@ -81,7 +81,7 @@ sub remove_first($$) {
 			return;
 		}
 	}
-	Meta::Utils::System::die("unable to find element [".$elem."]");
+	throw Meta::Error::Simple("unable to find element [".$elem."]");
 }
 
 sub size($) {
@@ -141,7 +141,7 @@ Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111, USA.
 
 	MANIFEST: Carray.pm
 	PROJECT: meta
-	VERSION: 0.12
+	VERSION: 0.13
 
 =head1 SYNOPSIS
 
@@ -264,10 +264,11 @@ None.
 	0.10 MV website construction
 	0.11 MV web site automation
 	0.12 MV SEE ALSO section fix
+	0.13 MV md5 issues
 
 =head1 SEE ALSO
 
-Meta::Utils::Arg(3), Meta::Utils::Output(3), Meta::Utils::System(3), strict(3)
+Meta::Error::Simple(3), Meta::Utils::Arg(3), Meta::Utils::Output(3), strict(3)
 
 =head1 TODO
 
