@@ -18,7 +18,7 @@ my($authors)=Meta::Info::Authors->new();
 my($revision)=Meta::Tool::Aegis::history($module,$authors);
 $revision->print(Meta::Utils::Output::get_file());
 
-Meta::Utils::System::exit(1);
+Meta::Utils::System::exit_ok();
 
 __END__
 
@@ -51,7 +51,7 @@ Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111, USA.
 
 	MANIFEST: fhist_ahistory.pl
 	PROJECT: meta
-	VERSION: 0.08
+	VERSION: 0.09
 
 =head1 SYNOPSIS
 
@@ -132,6 +132,7 @@ None.
 	0.06 MV SEE ALSO section fix
 	0.07 MV move tests to modules
 	0.08 MV bring movie data
+	0.09 MV md5 issues
 
 =head1 SEE ALSO
 
