@@ -16,7 +16,7 @@ $opts->analyze(\@ARGV);
 my($revision)=Meta::Tool::Fhist::history($module);
 $revision->print(Meta::Utils::Output::get_file());
 
-Meta::Utils::System::exit(1);
+Meta::Utils::System::exit_ok();
 
 __END__
 
@@ -49,7 +49,7 @@ Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111, USA.
 
 	MANIFEST: fhist_history.pl
 	PROJECT: meta
-	VERSION: 0.07
+	VERSION: 0.08
 
 =head1 SYNOPSIS
 
@@ -129,6 +129,7 @@ None.
 	0.05 MV web site automation
 	0.06 MV SEE ALSO section fix
 	0.07 MV move tests to modules
+	0.08 MV md5 issues
 
 =head1 SEE ALSO
 
