@@ -9,19 +9,19 @@ use Meta::Utils::Output qw();
 my($opts)=Meta::Utils::Opts::Opts->new();
 $opts->set_standard();
 $opts->set_free_allo(1);
-$opts->set_free_stri("[clas]");
+$opts->set_free_stri("[class]");
 $opts->set_free_mini(1);
 $opts->set_free_maxi(1);
 $opts->analyze(\@ARGV);
 
-my($clas)=($ARGV[0]);
-if($clas=~/\.class$/) {
-	$clas=Meta::Baseline::Aegis::which($clas);
-	$clas=~s/\//\./g;
-	($clas)=($clas=~/^.*\.java\.lib\.(.*)\.class$/);
+my($class)=($ARGV[0]);
+if($class=~/\.class$/) {
+	$class=Meta::Baseline::Aegis::which($class);
+	$class=~s/\//\./g;
+	($class)=($class=~/^.*\.java\.lib\.(.*)\.class$/);
 }
-#Meta::Utils::Output::print("running [".$clas."]\n");
-my($scod)=Meta::Utils::System::system_nodie("java",[$clas]);
+#Meta::Utils::Output::print("running [".$class."]\n");
+my($scod)=Meta::Utils::System::system_nodie("java",[$class]);
 Meta::Utils::System::exit($scod);
 
 __END__
@@ -55,7 +55,7 @@ Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111, USA.
 
 	MANIFEST: java_run.pl
 	PROJECT: meta
-	VERSION: 0.01
+	VERSION: 0.02
 
 =head1 SYNOPSIS
 
@@ -127,6 +127,7 @@ None.
 
 	0.00 MV put all tests in modules
 	0.01 MV move tests to modules
+	0.02 MV md5 issues
 
 =head1 SEE ALSO
 
