@@ -21,7 +21,7 @@ $uploader->set_do_ftp($do_ftp);
 $uploader->set_do_http($do_http);
 $uploader->fast_upload($perlpkg);
 
-Meta::Utils::System::exit(1);
+Meta::Utils::System::exit_ok();
 
 __END__
 
@@ -54,7 +54,7 @@ Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111, USA.
 
 	MANIFEST: perl_upload.pl
 	PROJECT: meta
-	VERSION: 0.01
+	VERSION: 0.02
 
 =head1 SYNOPSIS
 
@@ -143,6 +143,7 @@ None.
 
 	0.00 MV move tests to modules
 	0.01 MV weblog issues
+	0.02 MV md5 issues
 
 =head1 SEE ALSO
 
