@@ -18,7 +18,7 @@ $module->set_name($file);
 my($games)=$module->get_pgn_games();
 Meta::Utils::Output::print("number of games is [".$games."]\n");
 
-Meta::Utils::System::exit(1);
+Meta::Utils::System::exit_ok();
 
 __END__
 
@@ -51,7 +51,7 @@ Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111, USA.
 
 	MANIFEST: chess_pgn_stats.pl
 	PROJECT: meta
-	VERSION: 0.01
+	VERSION: 0.02
 
 =head1 SYNOPSIS
 
@@ -129,6 +129,7 @@ None.
 
 	0.00 MV SEE ALSO section fix
 	0.01 MV move tests to modules
+	0.02 MV md5 issues
 
 =head1 SEE ALSO
 
