@@ -31,7 +31,7 @@ my($game_number)=$doc->getElementsByTagName("game")->getLength();
 Meta::Utils::Output::print("number of opponents is [".$opponent_number."]\n");
 Meta::Utils::Output::print("number of games is [".$game_number."]\n");
 
-Meta::Utils::System::exit(1);
+Meta::Utils::System::exit_ok();
 
 __END__
 
@@ -64,7 +64,7 @@ Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111, USA.
 
 	MANIFEST: chess_stats.pl
 	PROJECT: meta
-	VERSION: 0.11
+	VERSION: 0.12
 
 =head1 SYNOPSIS
 
@@ -161,6 +161,7 @@ None.
 	0.09 MV web site automation
 	0.10 MV SEE ALSO section fix
 	0.11 MV move tests to modules
+	0.12 MV md5 issues
 
 =head1 SEE ALSO
 
