@@ -29,7 +29,7 @@ my($contact_number)=$doc->getElementsByTagName("contact")->getLength();
 
 Meta::Utils::Output::print("number of contact is [".$contact_number."]\n");
 
-Meta::Utils::System::exit(1);
+Meta::Utils::System::exit_ok();
 
 __END__
 
@@ -62,7 +62,7 @@ Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111, USA.
 
 	MANIFEST: contacts_stats.pl
 	PROJECT: meta
-	VERSION: 0.02
+	VERSION: 0.03
 
 =head1 SYNOPSIS
 
@@ -144,6 +144,7 @@ None.
 	0.00 MV web site automation
 	0.01 MV SEE ALSO section fix
 	0.02 MV move tests to modules
+	0.03 MV md5 issues
 
 =head1 SEE ALSO
 
