@@ -12,7 +12,7 @@ $opts->set_free_mini(1);
 $opts->set_free_maxi(1);
 $opts->analyze(\@ARGV);
 
-Meta::Utils::System::exit(1);
+Meta::Utils::System::exit_ok();
 
 __END__
 
@@ -45,7 +45,7 @@ Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111, USA.
 
 	MANIFEST: dbman_find.pl
 	PROJECT: meta
-	VERSION: 0.07
+	VERSION: 0.08
 
 =head1 SYNOPSIS
 
@@ -143,6 +143,7 @@ None.
 	0.05 MV web site automation
 	0.06 MV SEE ALSO section fix
 	0.07 MV move tests to modules
+	0.08 MV md5 issues
 
 =head1 SEE ALSO
 
