@@ -40,7 +40,7 @@ print $p->sql_table($stat,$def,$dbi,$limit);
 #print $p->core_code($stat,$def,$dbi,$limit,$columns);
 print $p->end_html();
 
-Meta::Utils::System::exit(1);
+Meta::Utils::System::exit_ok();
 
 __END__
 
@@ -73,7 +73,7 @@ Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111, USA.
 
 	MANIFEST: movie_cgi.pl
 	PROJECT: meta
-	VERSION: 0.07
+	VERSION: 0.08
 
 =head1 SYNOPSIS
 
@@ -175,6 +175,7 @@ None.
 	0.05 MV download scripts
 	0.06 MV bring movie data
 	0.07 MV weblog issues
+	0.08 MV md5 issues
 
 =head1 SEE ALSO
 
