@@ -53,7 +53,7 @@ $pdmt->get_graph()->set_verbose(1);
 
 $shell->run();
 
-Meta::Utils::System::exit(1);
+Meta::Utils::System::exit_ok();
 
 __END__
 
@@ -86,7 +86,7 @@ Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111, USA.
 
 	MANIFEST: pdmt.pl
 	PROJECT: meta
-	VERSION: 0.13
+	VERSION: 0.14
 
 =head1 SYNOPSIS
 
@@ -208,6 +208,7 @@ None.
 	0.11 MV move tests to modules
 	0.12 MV teachers project
 	0.13 MV more pdmt stuff
+	0.14 MV md5 issues
 
 =head1 SEE ALSO
 
