@@ -30,7 +30,7 @@ my($done_item_number)=$done_doc->getElementsByTagName("item")->getLength();
 Meta::Utils::Output::print("number of items is [".$item_number."]\n");
 Meta::Utils::Output::print("number of done items is [".$done_item_number."]\n");
 
-Meta::Utils::System::exit(1);
+Meta::Utils::System::exit_ok();
 
 __END__
 
@@ -63,7 +63,7 @@ Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111, USA.
 
 	MANIFEST: todo_stats.pl
 	PROJECT: meta
-	VERSION: 0.12
+	VERSION: 0.13
 
 =head1 SYNOPSIS
 
@@ -161,6 +161,7 @@ None.
 	0.10 MV web site automation
 	0.11 MV SEE ALSO section fix
 	0.12 MV move tests to modules
+	0.13 MV md5 issues
 
 =head1 SEE ALSO
 
