@@ -30,7 +30,7 @@ for(my($i)=0;$i<=$#ARGV;$i++) {
 	Meta::Utils::Output::print("blksize is [".$sb->blksize()."]\n");
 	Meta::Utils::Output::print("blocks is [".$sb->blocks()."]\n");
 }
-Meta::Utils::System::exit(1);
+Meta::Utils::System::exit_ok();
 
 __END__
 
@@ -63,7 +63,7 @@ Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111, USA.
 
 	MANIFEST: utils_stat.pl
 	PROJECT: meta
-	VERSION: 0.07
+	VERSION: 0.08
 
 =head1 SYNOPSIS
 
@@ -141,6 +141,7 @@ None.
 	0.05 MV web site automation
 	0.06 MV SEE ALSO section fix
 	0.07 MV move tests to modules
+	0.08 MV md5 issues
 
 =head1 SEE ALSO
 
