@@ -34,7 +34,7 @@ print $p->start_html(
 print $p->sql_table($stat,$def,$dbi,$limit);
 print $p->end_html();
 
-Meta::Utils::System::exit(1);
+Meta::Utils::System::exit_ok();
 
 __END__
 
@@ -67,7 +67,7 @@ Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111, USA.
 
 	MANIFEST: weblog_cgi.pl
 	PROJECT: meta
-	VERSION: 0.03
+	VERSION: 0.04
 
 =head1 SYNOPSIS
 
@@ -165,6 +165,7 @@ None.
 	0.01 MV web site development
 	0.02 MV weblog issues
 	0.03 MV teachers project
+	0.04 MV md5 issues
 
 =head1 SEE ALSO
 
@@ -172,4 +173,4 @@ Meta::Cgi::SqlTable(3), Meta::Db::Dbi(3), Meta::Db::Def(3), Meta::Utils::Opts::O
 
 =head1 TODO
 
-Nothing.
+-get the title and style from some db global defs connection or some xml.
