@@ -18,7 +18,7 @@ Meta::Baseline::Test::redirect_on();
 
 Meta::Baseline::Test::redirect_off();
 
-Meta::Utils::System::exit(1);
+Meta::Utils::System::exit_ok();
 
 __END__
 
@@ -51,7 +51,7 @@ Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111, USA.
 
 	MANIFEST: ansicolor.pl
 	PROJECT: meta
-	VERSION: 0.19
+	VERSION: 0.20
 
 =head1 SYNOPSIS
 
@@ -138,6 +138,7 @@ None.
 	0.17 MV web site automation
 	0.18 MV SEE ALSO section fix
 	0.19 MV move tests to modules
+	0.20 MV md5 issues
 
 =head1 SEE ALSO
 
