@@ -17,7 +17,7 @@ Gtk->init();
 
 Meta::Baseline::Test::redirect_off();
 
-Meta::Utils::System::exit(1);
+Meta::Utils::System::exit_ok();
 
 __END__
 
@@ -50,7 +50,7 @@ Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111, USA.
 
 	MANIFEST: gtk.pl
 	PROJECT: meta
-	VERSION: 0.19
+	VERSION: 0.20
 
 =head1 SYNOPSIS
 
@@ -137,6 +137,7 @@ None.
 	0.17 MV web site automation
 	0.18 MV SEE ALSO section fix
 	0.19 MV move tests to modules
+	0.20 MV md5 issues
 
 =head1 SEE ALSO
 
