@@ -21,7 +21,7 @@ $checker->parse_from_file($module,Meta::Utils::Output::get_handle());
 
 Meta::Baseline::Test::redirect_off();
 
-Meta::Utils::System::exit(1);
+Meta::Utils::System::exit_ok();
 
 __END__
 
@@ -54,7 +54,7 @@ Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111, USA.
 
 	MANIFEST: pod_checker.pl
 	PROJECT: meta
-	VERSION: 0.08
+	VERSION: 0.09
 
 =head1 SYNOPSIS
 
@@ -131,6 +131,7 @@ None.
 	0.06 MV web site automation
 	0.07 MV SEE ALSO section fix
 	0.08 MV move tests to modules
+	0.09 MV md5 issues
 
 =head1 SEE ALSO
 
