@@ -22,7 +22,7 @@ $game->pgn_write(Meta::Utils::Output::get_file());
 
 Meta::Baseline::Test::redirect_off();
 
-Meta::Utils::System::exit(1);
+Meta::Utils::System::exit_ok();
 
 __END__
 
@@ -55,7 +55,7 @@ Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111, USA.
 
 	MANIFEST: game.pl
 	PROJECT: meta
-	VERSION: 0.15
+	VERSION: 0.16
 
 =head1 SYNOPSIS
 
@@ -139,6 +139,7 @@ None.
 	0.13 MV web site automation
 	0.14 MV SEE ALSO section fix
 	0.15 MV move tests to modules
+	0.16 MV md5 issues
 
 =head1 SEE ALSO
 
