@@ -42,7 +42,7 @@ Meta::Utils::Output::print("join is [".$arr->join(":")."]\n");
 
 Meta::Baseline::Test::redirect_off();
 
-Meta::Utils::System::exit(1);
+Meta::Utils::System::exit_ok();
 
 __END__
 
@@ -75,7 +75,7 @@ Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111, USA.
 
 	MANIFEST: array.pl
 	PROJECT: meta
-	VERSION: 0.21
+	VERSION: 0.22
 
 =head1 SYNOPSIS
 
@@ -165,6 +165,7 @@ None.
 	0.19 MV web site automation
 	0.20 MV SEE ALSO section fix
 	0.21 MV move tests to modules
+	0.22 MV md5 issues
 
 =head1 SEE ALSO
 
