@@ -25,7 +25,7 @@ for(my($i)=0;$i<$rang->num_ranges();$i++) {
 
 Meta::Baseline::Test::redirect_off();
 
-Meta::Utils::System::exit(1);
+Meta::Utils::System::exit_ok();
 
 __END__
 
@@ -58,7 +58,7 @@ Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111, USA.
 
 	MANIFEST: ranges.pl
 	PROJECT: meta
-	VERSION: 0.26
+	VERSION: 0.27
 
 =head1 SYNOPSIS
 
@@ -153,6 +153,7 @@ None.
 	0.24 MV web site automation
 	0.25 MV SEE ALSO section fix
 	0.26 MV move tests to modules
+	0.27 MV md5 issues
 
 =head1 SEE ALSO
 
