@@ -22,7 +22,7 @@ my($host)=Meta::Baseline::Test::get_host();
 
 Meta::Baseline::Test::redirect_off();
 
-Meta::Utils::System::exit(1);
+Meta::Utils::System::exit_ok();
 
 __END__
 
@@ -55,7 +55,7 @@ Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111, USA.
 
 	MANIFEST: cp.pl
 	PROJECT: meta
-	VERSION: 0.21
+	VERSION: 0.22
 
 =head1 SYNOPSIS
 
@@ -144,6 +144,7 @@ None.
 	0.19 MV web site automation
 	0.20 MV SEE ALSO section fix
 	0.21 MV move tests to modules
+	0.22 MV md5 issues
 
 =head1 SEE ALSO
 
