@@ -40,7 +40,7 @@ do_proc();
 
 Meta::Baseline::Test::redirect_off();
 
-Meta::Utils::System::exit(1);
+Meta::Utils::System::exit_ok();
 
 __END__
 
@@ -73,7 +73,7 @@ Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111, USA.
 
 	MANIFEST: text.pl
 	PROJECT: meta
-	VERSION: 0.20
+	VERSION: 0.21
 
 =head1 SYNOPSIS
 
@@ -165,6 +165,7 @@ None.
 	0.18 MV web site automation
 	0.19 MV SEE ALSO section fix
 	0.20 MV move tests to modules
+	0.21 MV md5 issues
 
 =head1 SEE ALSO
 
