@@ -15,7 +15,7 @@ Meta::Baseline::Test::redirect_on();
 
 Meta::Baseline::Test::redirect_off();
 
-Meta::Utils::System::exit(1);
+Meta::Utils::System::exit_ok();
 
 __END__
 
@@ -48,7 +48,7 @@ Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111, USA.
 
 	MANIFEST: debug.pl
 	PROJECT: meta
-	VERSION: 0.17
+	VERSION: 0.18
 
 =head1 SYNOPSIS
 
@@ -133,6 +133,7 @@ None.
 	0.15 MV web site automation
 	0.16 MV SEE ALSO section fix
 	0.17 MV move tests to modules
+	0.18 MV md5 issues
 
 =head1 SEE ALSO
 
