@@ -29,7 +29,7 @@ Meta::Utils::Output::print("out is [".$out."]\n");
 
 Meta::Baseline::Test::redirect_off();
 
-Meta::Utils::System::exit(1);
+Meta::Utils::System::exit_ok();
 
 __END__
 
@@ -62,7 +62,7 @@ Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111, USA.
 
 	MANIFEST: system.pl
 	PROJECT: meta
-	VERSION: 0.21
+	VERSION: 0.22
 
 =head1 SYNOPSIS
 
@@ -151,6 +151,7 @@ None.
 	0.19 MV SEE ALSO section fix
 	0.20 MV move tests to modules
 	0.21 MV download scripts
+	0.22 MV md5 issues
 
 =head1 SEE ALSO
 
