@@ -14,7 +14,7 @@ Meta::Baseline::Test::redirect_on();
 #doit 
 Meta::Baseline::Test::redirect_off();
 
-Meta::Utils::System::exit(1);
+Meta::Utils::System::exit_ok();
 
 __END__
 
@@ -47,7 +47,7 @@ Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111, USA.
 
 	MANIFEST: import_export.pl
 	PROJECT: meta
-	VERSION: 0.24
+	VERSION: 0.25
 
 =head1 SYNOPSIS
 
@@ -146,6 +146,7 @@ None.
 	0.22 MV web site automation
 	0.23 MV SEE ALSO section fix
 	0.24 MV move tests to modules
+	0.25 MV md5 issues
 
 =head1 SEE ALSO
 
