@@ -3,34 +3,46 @@
 package Meta::Tool::Nm;
 
 use strict qw(vars refs subs);
+use Meta::Utils::File::Patho qw();
+use Meta::Ds::Set qw();
 
 our($VERSION,@ISA);
-$VERSION="0.10";
+$VERSION="0.11";
 @ISA=qw();
 
+#sub BEGIN();
 #sub read($);
 #sub TEST($);
 
 #__DATA__
 
+our($tool_path);
+
+sub BEGIN() {
+	my($patho)=Meta::Utils::File::Patho->new_path();
+	$tool_path=$patho->resolve("nm");
+}
+
 sub read($) {
 	my($file)=@_;
-	my(%hash);
-	my($prog)="/usr/bin/nm";
+	my($set)=Meta::Ds::Set->new();
 	#do the work
 	my($parser)=Meta::Utils::Parse::Text->new();
 	my(@args);
-	push(@args,$prog);
+	push(@args,$tool_path);
+	push(@args,"--dynamic");
 	push(@args,$file);
 	$parser->init_proc(\@args);
 	while(!$parser->get_over()) {
 		my($line)=$parser->get_line();
-		my($address,$type,$sym)=($line=~/^(.*)\s(.)\s(.*)$/);
-		$hash{$sym}=defined;
+		if($line=~/(.*)\sT\s(.*)$/) {
+			my($address,$type,$sym)=($line=~/^(.*)\s(.)\s(.*)$/);
+			$set->write($sym);
+		}
 		$parser->next();
 	}
 	$parser->fini();
-	return(\%hash);
+	return($set);
 }
 
 sub TEST($) {
@@ -71,7 +83,7 @@ Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111, USA.
 
 	MANIFEST: Nm.pm
 	PROJECT: meta
-	VERSION: 0.10
+	VERSION: 0.11
 
 =head1 SYNOPSIS
 
@@ -88,6 +100,7 @@ return a hash containing the symbols in that file.
 
 =head1 FUNCTIONS
 
+	BEGIN()
 	read($)
 	TEST($)
 
@@ -95,6 +108,10 @@ return a hash containing the symbols in that file.
 
 =over 4
 
+=item B<BEGIN()>
+
+Bootstrap method to find nm.
+
 =item B<read($)>
 
 This function received a file name and runs nm on the file storing
@@ -135,11 +152,12 @@ None.
 	0.08 MV website construction
 	0.09 MV web site automation
 	0.10 MV SEE ALSO section fix
+	0.11 MV md5 issues
 
 =head1 SEE ALSO
 
-strict(3)
+Meta::Ds::Set(3), Meta::Utils::File::Patho(3), strict(3)
 
 =head1 TODO
 
-Nothing.
+-check that the file received is indeed a shared library using File::MMagic.
