@@ -16,7 +16,7 @@ my($window)=Meta::Widget::Gtk::Db::Connection->new();
 $window->show();
 Gtk->main();
 
-Meta::Utils::System::exit(1);
+Meta::Utils::System::exit_ok();
 
 __END__
 
@@ -49,7 +49,7 @@ Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111, USA.
 
 	MANIFEST: connection.pl
 	PROJECT: meta
-	VERSION: 0.18
+	VERSION: 0.19
 
 =head1 SYNOPSIS
 
@@ -136,6 +136,7 @@ None.
 	0.16 MV web site automation
 	0.17 MV SEE ALSO section fix
 	0.18 MV move tests to modules
+	0.19 MV md5 issues
 
 =head1 SEE ALSO
 
