@@ -5,7 +5,7 @@ package Meta::Utils::Net::Rm;
 use strict qw(vars refs subs);
 
 our($VERSION,@ISA);
-$VERSION="0.25";
+$VERSION="0.26";
 @ISA=qw();
 
 #sub doit($$$$$$);
@@ -56,7 +56,7 @@ Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111, USA.
 
 	MANIFEST: Rm.pm
 	PROJECT: meta
-	VERSION: 0.25
+	VERSION: 0.26
 
 =head1 SYNOPSIS
 
@@ -64,7 +64,7 @@ Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111, USA.
 	use Meta::Utils::Net::Rm qw();
 	my($stat)=Meta::Utils::Net::Rm::doit([params]);
 	if(!$stat) {
-		Meta::Utils::System::die("unable to remove files on remove machine");
+		throw Meta::Error::Simple("unable to remove files on remove machine");
 	}
 
 =head1 DESCRIPTION
@@ -135,6 +135,7 @@ None.
 	0.23 MV website construction
 	0.24 MV web site automation
 	0.25 MV SEE ALSO section fix
+	0.26 MV md5 issues
 
 =head1 SEE ALSO
 
