@@ -7,11 +7,12 @@ use IO::Handle qw();
 use Data::Dumper qw();
 
 our($VERSION,@ISA);
-$VERSION="0.15";
+$VERSION="0.16";
 @ISA=qw();
 
 #sub BEGIN();
 #sub print($);
+#sub println($);
 #sub verbose($$);
 #sub dump($);
 #sub verbose_dump($$);
@@ -37,6 +38,11 @@ sub print($) {
 	}
 }
 
+sub println($) {
+	my($stri)=@_;
+	&print($stri."\n");
+}
+
 sub verbose($$) {
 	my($verb,$stri)=@_;
 	if($verb) {
@@ -114,7 +120,7 @@ Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111, USA.
 
 	MANIFEST: Output.pm
 	PROJECT: meta
-	VERSION: 0.15
+	VERSION: 0.16
 
 =head1 SYNOPSIS
 
@@ -135,6 +141,7 @@ this is a SPECIAL STDERR FILE
 
 	BEGIN()
 	print($)
+	println($)
 	verbose($$)
 	dump($)
 	verbose_dump($$)
@@ -160,6 +167,10 @@ so.
 
 This prints out an output message to the console.
 
+=item B<println($)>
+
+This method prints out it's argument with newline attached.
+
 =item B<verbose($$)>
 
 This method prints out an output message to the console only if the first
@@ -231,6 +242,7 @@ None.
 	0.13 MV SEE ALSO section fix
 	0.14 MV finish papers
 	0.15 MV teachers project
+	0.16 MV md5 issues
 
 =head1 SEE ALSO
 
