@@ -8,7 +8,7 @@ use XML::DOM qw();
 use Meta::Baseline::Aegis qw();
 
 our($VERSION,@ISA);
-$VERSION="0.10";
+$VERSION="0.11";
 @ISA=qw();
 
 #sub new($);
@@ -20,22 +20,22 @@ $VERSION="0.10";
 #__DATA__
 
 sub new($) {
-	my($clas)=@_;
+	my($class)=@_;
 	my($self)={};
 	$self->{PARSER}=XML::DOM::ValParser->new();
-	bless($self,$clas);
+	bless($self,$class);
 	return($self);
 }
 
 sub new_vali($$) {
-	my($clas,$vali)=@_;
+	my($class,$vali)=@_;
 	my($self)={};
 	if($vali) {
 		$self->{PARSER}=XML::DOM::ValParser->new();
 	} else {
 		$self->{PARSER}=XML::DOM::Parser->new();
 	}
-	bless($self,$clas);
+	bless($self,$class);
 	return($self);
 }
 
@@ -87,7 +87,7 @@ Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111, USA.
 
 	MANIFEST: Dom.pm
 	PROJECT: meta
-	VERSION: 0.10
+	VERSION: 0.11
 
 =head1 SYNOPSIS
 
@@ -169,6 +169,7 @@ None.
 	0.08 MV website construction
 	0.09 MV web site automation
 	0.10 MV SEE ALSO section fix
+	0.11 MV md5 issues
 
 =head1 SEE ALSO
 
