@@ -9,7 +9,7 @@ use Meta::Baseline::Aegis qw();
 use Meta::Utils::File::File qw();
 
 our($VERSION,@ISA);
-$VERSION="0.10";
+$VERSION="0.11";
 @ISA=qw(XML::Checker::Parser);
 
 #sub new($);
@@ -19,22 +19,23 @@ $VERSION="0.10";
 #__DATA__
 
 sub new($) {
-	my($clas)=@_;
-	my($self)=XML::Checker::Parser->new();
+	my($class)=@_;
+	my($self)=XML::Checker::Parser::new($class);
 	if(!$self) {
-		Meta::Utils::System::die("didn't get a parser");
+		throw Meta::Error::Simple("didn't get a parser");
 	}
 	$self->setHandlers(
 		'ExternEnt'=>\&handle_externent,
 	);
-	bless($self,$clas);
+	#bless($self,$class);
 	return($self);
 }
 
 sub handle_externent($$$$) {
 	my($self,$base,$sysi,$pubi)=@_;
 	my($find)=Meta::Baseline::Aegis::which($sysi);
-	my($data)=Meta::Utils::File::File::load($find);
+	my($data);
+	Meta::Utils::File::File::load($find,\$data);
 	Meta::Utils::Output::print("in handle_externent\n");
 	Meta::Utils::Output::print("base is [".$base."]\n");
 	Meta::Utils::Output::print("sysi is [".$sysi."]\n");
@@ -80,7 +81,7 @@ Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111, USA.
 
 	MANIFEST: Checker.pm
 	PROJECT: meta
-	VERSION: 0.10
+	VERSION: 0.11
 
 =head1 SYNOPSIS
 
@@ -150,6 +151,7 @@ None.
 	0.08 MV web site automation
 	0.09 MV SEE ALSO section fix
 	0.10 MV move tests into modules
+	0.11 MV md5 issues
 
 =head1 SEE ALSO
 
